bayespy.inference.vmp.transformations.RotateVaryingMarkovChain.rotate
=====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateVaryingMarkovChain.rotate